==> groupoffice-com-4.0.47.tar.gz: groupoffice-com-4.0.47/modules/sieve/language/en.php <==
<?php


$l["name"]= 'Sieve';
$l["scriptname"]= 'Script name';
$l["index"]= 'Index';
$l["test"]= 'Test';
$l["not"]= 'Not';
$l["type"]= 'Type';
$l["arg"]= 'Argument';
$l["arg1"]= 'Argument1';
$l["arg2"]= 'Argument2';
$l["copy"]= 'Copy';
$l["target"]= 'Target';
$l["sieverules"]= 'Rules';
$l["activatedrules"]= 'Activated rules';
$l["field"]= 'Field';
$l["operator"]= 'Operator';
$l["rules"]= 'Message';
$l["actions"]= 'Actions';
$l["editsieve"]= 'Edit rule';
$l["action"]= 'Action';
$l["ruletext"]= 'For incoming emails';
$l["actiontext"]= '...apply the following actions';
$l["clear"]= 'Clear';
$l["active"]= 'Active';
$l["activate"]= 'Activate filterset';
$l["filterset"]= 'Filterset:';
$l["days"]= 'Reply every x days';
$l["addresses"]= 'Also reply for these aliases';
$l["reason"]= 'Message';
$l["allfollowingrules"]= 'that meet the following rules';
$l["somefollowingrules"]= 'that meet one of the following rules';
$l["allmessages"]= 'all messages';
$l["disablefilter"]= 'Disable filter';
$l["newsieverule"]= 'New rule';
$l["checksieveerror"]= 'Error while checking for sieve support';
$l["erroremptygrids"]= 'One or both grids are empty.';
$l["errorineditmode"]= 'You are currently editing an item!\n Please finish that action first.';
$l["subject"]= 'subject';
$l["from"]= 'sender';
$l["to"]= 'recipient';
$l["size"]= 'size';
$l["contains"]= 'contains';
$l["notcontains"]= 'doesn\'t contain';
$l["is"]= 'equals';
$l["notis"]= 'doesn\'t equal';
$l["exists"]= 'exists';
$l["notexists"]= 'doesn\'t exist';
$l["fileinto"]= 'Move message to';
$l["copyto"]= 'Copy message to';
$l["redirect"]= 'Forward to';
$l["redirect_to"]= 'Copy to e-mail';
$l["vacation"]= 'Vacation';
$l["reject"]= 'Reject with message';
$l["discard"]= 'Discard';
$l["stop"]= 'Stop';
$l["under"]= 'Under';
$l["over"]= 'Over';
$l["disabled"]= 'Disabled';
$l["subjectcontainsnot"]= 'Subject doesn\'t contain';
$l["fromcontainsnot"]= 'Sender doesn\'t contain';
$l["tocontainsnot"]= 'Recipient doesn\'t contain';
$l["subjectcontains"]= 'Subject contains';
$l["fromcontains"]= 'Sender contains';
$l["tocontains"]= 'Recipient contains';
$l["subjectexistsnot"]= 'Subject doesn\'t exist';
$l["fromexistsnot"]= 'Sender doesn\'t exist';
$l["toexistsnot"]= 'Recipient doesn\'t exist';
$l["subjectexists"]= 'Subject exists';
$l["fromexists"]= 'Sender exists';
$l["toexists"]= 'Recipient exists';
$l["markedasspam"]= 'Marked as spam';
$l["sizesmallerthan"]= 'Grootte is kleiner dan';
$l["sizebiggerthan"]= 'Grootte is groter dan';
$l["errorshowtext"]= 'Error while displaying test line';
$l["sendcopyto"]= 'Forward a copy to';
$l["forwardto"]= 'Forward to ';
$l["vacsendevery"]= 'Vacation: Send message every';
$l["vacdaystoadresses"]= 'day(s) to the address(es)';
$l["vacationmessage"]= 'Message:';
$l["refusewithmesssage"]= 'Reject with message:';
$l["spamflag"]= 'Spam flag';
$l["custom"]= 'Custom';
$l["custommailheader"]= 'Mailheader:';
$l["replyToMessage"]='Reply to message';
$l["subjectequals"]= 'Subject equals';
$l["subjectequalsnot"]= 'Subject is not equal to';
$l["fromequals"]= 'From equals';
$l["fromequalsnot"]= 'From is not equal to';
$l["toequals"]= 'To equals';
$l["toequalsnot"]= 'To is not equal to';
$l['name']='Sieve';
$l['description']='Manage sieve e-mail filtering rules';
$l['active']='active';
$l['standardvacation']='Standard vacation rule';
$l['standardvacationmessage']='I am on vacation';

==> groupoffice-com-4.0.97.tar.gz: groupoffice-com-4.0.97/modules/sieve/language/en.php <==
<?php


$l["name"]= 'Sieve';
$l["scriptname"]= 'Script name';
$l["index"]= 'Index';
$l["test"]= 'Test';
$l["not"]= 'Not';
$l["type"]= 'Type';
$l["arg"]= 'Argument';
$l["arg1"]= 'Argument1';
$l["arg2"]= 'Argument2';
$l["copy"]= 'Copy';
$l["target"]= 'Target';
$l["sieverules"]= 'Rules';
$l["activatedrules"]= 'Activated rules';
$l["field"]= 'Field';
$l["operator"]= 'Operator';
$l["rules"]= 'Message';
$l["actions"]= 'Actions';
$l["editsieve"]= 'Edit rule';
$l["action"]= 'Action';
$l["ruletext"]= 'For incoming emails';
$l["actiontext"]= '...execute the following actions';
$l["clear"]= 'Clear';
$l["active"]= 'Active';
$l["activate"]= 'Activate filterset';
$l["filterset"]= 'Filterset:';
$l["days"]= 'Reply every x days';
$l["sendToAddresses"]='Send mail to these email addresses';
$l["addressesLabel"]= 'Send mail to these email addresses (separated by comma)';
$l["addressesLabelOptional"]= '(optional) Activate for these aliases too (separated by comma)';
$l["reason"]= 'Message';
$l["allfollowingrules"]= 'that meet the following criteria';
$l["somefollowingrules"]= 'that meet at least one of the following criteria';
$l["allmessages"]= 'all incoming emails';
$l["disablefilter"]= 'Disable filter';
$l["newsieverule"]= 'New rule';
$l["checksieveerror"]= 'Error while checking for sieve support';
$l["erroremptygrids"]= 'One or both grids are empty.';
$l["errorineditmode"]= 'You are currently editing an item!\n Please finish that action first.';
$l["subject"]= 'subject';
$l["from"]= 'sender';
$l["to"]= 'recipient';
$l["size"]= 'size';
$l["contains"]= 'contains';
$l["notcontains"]= 'doesn\'t contain';
$l["is"]= 'equals';
$l["notis"]= 'doesn\'t equal';
$l["exists"]= 'exists';
$l["notexists"]= 'doesn\'t exist';
$l["fileinto"]= 'Move email to the folder';
$l["fileintoLabel"]= 'Move email to selected folder';
$l["copyto"]= 'Copy email to the folder';
$l["copytoLabel"]= 'Copy email to selected folder';
$l["redirect_to"]= 'Forward to';
$l["redirect_copy_to"]= 'Copy to e-mail';
$l["vacation"]= 'Vacation';
$l["reject"]= 'Reject with message';
$l["toFolder"]= 'To folder';
$l["discard"]= 'Discard';
$l["stop"]= 'Stop';
$l["under"]= 'Under';
$l["over"]= 'Over';
$l["disabled"]= 'Disabled';
$l["subjectcontainsnot"]= 'Subject doesn\'t contain';
$l["fromcontainsnot"]= 'Sender doesn\'t contain';
$l["tocontainsnot"]= 'Recipient doesn\'t contain';
$l["subjectcontains"]= 'Subject contains';
$l["fromcontains"]= 'Sender contains';
$l["tocontains"]= 'Recipient contains';
$l["subjectexistsnot"]= 'Subject doesn\'t exist';
$l["fromexistsnot"]= 'Sender doesn\'t exist';
$l["toexistsnot"]= 'Recipient doesn\'t exist';
$l["subjectexists"]= 'Subject exists';
$l["fromexists"]= 'Sender exists';
$l["toexists"]= 'Recipient exists';
$l["markedasspam"]= 'Marked as spam';
$l["sizesmallerthan"]= 'Grootte is kleiner dan';
$l["sizebiggerthan"]= 'Grootte is groter dan';
$l["errorshowtext"]= 'Error while displaying test line';
$l["sendcopyto"]= 'Forward a copy to';
$l["forwardto"]= 'Forward to';
$l["vacsendevery"]= 'Reply every';
$l["vacsendevery2"]= 'day(s)';
$l["vacAlsoMailTo"]= 'Also email message to';
$l["vacationmessage"]= 'Message:';
$l["refusewithmesssage"]= 'Reject with message:';
$l["spamflag"]= 'Spam flag';
$l["custom"]= 'Custom';
$l["custommailheader"]= 'Mailheader:';
$l["replyToMessage"]='Reply to message';
$l["subjectequals"]= 'Subject equals';
$l["subjectequalsnot"]= 'Subject is not equal to';
$l["fromequals"]= 'From equals';
$l["fromequalsnot"]= 'From is not equal to';
$l["toequals"]= 'To equals';
$l["toequalsnot"]= 'To is not equal to';
$l['name']='Sieve';
$l['description']='Manage sieve e-mail filtering rules';
$l['active']='active';
$l['standardvacation']='Standard vacation rule';
$l['standardvacationmessage']='I am on vacation';

$l['setAction']='Set action';
$l['setFilter']='Set criterium';
$l['sievePort']='Sieve filter port number';
$l['useTLS']='Use secure connection for (Sieve) email filters';
$l['cmdSaveChanges']='Save changes';
$l['pleaseAddCriterium']='Please click \'add\' to add a criterium';
$l['pleaseAddAction']='Please click \'add\' to add an action';
$l['meetingTheseCriteria']='meeting these criteria';
$l['pleaseSelectOne']='Please make a selection';
$l['vacationStart']='First day of this message';
$l['vacationEnd']='Last day of this message';

$l['activateFilter']='Activate this filter';
$l['active']='Active';
$l['sieveWarning']="If your IMAP server supports sieve filters. It's recommended to use those instead. Please try the 'Sieve filters' tab first.";
$l['setRead']='Mark message as read';
